@@ -3,33 +3,35 @@ use warnings;
 package Dist::Zilla::Plugin::Run::Clean;
 # ABSTRACT: execute a command of the distribution on 'dzil clean'
 # vim: set ts=8 sw=4 tw=78 et :
-our $VERSION = '0.033';
+
+our $VERSION = '0.034';
+
 use Moose;
 with
     'Dist::Zilla::Role::Plugin',
     'Dist::Zilla::Plugin::Run::Role::Runner';
 
 use Moose::Util ();
-use Scalar::Util 'weaken';
 use namespace::autoclean;
 
-sub BUILD {
-    my $plugin = shift;
-
-    # when the zilla is demolished, allow the ourselves to be destroyed too
-    weaken $plugin;
-
-    # Dist::Zilla really ought to have a -CleanerProvider hook...
-    Moose::Util::add_method_modifier($plugin->zilla->meta, 'after',
+{
+    use Dist::Zilla::Dist::Builder;
+    my $meta = Dist::Zilla::Dist::Builder->meta;
+    $meta->make_mutable;
+    Moose::Util::add_method_modifier($meta, 'after',
         [
             clean => sub {
                 my ($zilla, $dry_run) = @_;
-                return if not $plugin;
-                $plugin->clean($dry_run);
+                foreach my $plugin (grep { $_->isa(__PACKAGE__) } @{ $zilla->plugins })
+                {
+                    # Dist::Zilla really ought to have a -CleanerProvider hook...
+                    $plugin->clean($dry_run);
+                }
             },
         ],
     );
-};
+    $meta->make_immutable;
+}
 
 sub clean
 {
@@ -62,7 +64,7 @@ Dist::Zilla::Plugin::Run::Clean - execute a command of the distribution on 'dzil
 
 =head1 VERSION
 
-version 0.033
+version 0.034
 
 =head1 SYNOPSIS
 
